function [c bound]=autocorr(y,lags)
% AUTOCORR      Autocorrelation function (normalized)
%
% c = autocorr(y,M,opt)
%
% Results are plotted if no output arguments are given.
%
%   Jenkins,G.M. and Watts,D.G., 1969. Spectral analysis and its
%   applications. Holden-Day series in time series analysis, 1, 513 pp.
%
% See also XCORR CORRCOEF COV ITS
if ~all([length(size(y))==2 , ismember(1, size(y))]); 
  error('y must be a vector');
end

if nargin == 1;
  lags = 0:(length(y)-2);
end;

nlag = length(lags);
ntim = length(y);
c = repmat(NaN, [nlag 1]);

for i = 1:nlag;
  ind1 = 1:(ntim-abs(lags(i)));
  ind2 = (1+abs(lags(i))):ntim;
  tem = corrcoef(y(ind1), y(ind2));
  c(i) = tem(1,2);
end

if nargout==0   
   
  %%bound 1
  upperBound = 1.96/sqrt(length(y))*ones(1,nlag);  
  lowerBound = -1.96/sqrt(length(y))*ones(1,nlag);
    
  % ... a plot
  figure %autocorr 4; clf;
%  if cols < 7
    plot(lags,c,'linewidth',2); %legend(strcat('x=',int2str([1:cols])));
    ylabel('r_h','fontsize',20);  grid;  zoom xon;
    hold on
    plot (lags,upperBound,'r--','linewidth',2);
    plot (lags,lowerBound,'b--','linewidth',2);
    
%   else
%     contourf(nlags,1:cols,c');
%     ecolorbar(c,[],'c_k'); ylabel('timeseries #');    
%     hold on
%     plot (0:M,upperBound);
%     plot (0:M,lowerBound);
%     
%   end
  xlabel('Lag h','fontsize',20); %title('Autocorrelation Function','fontsize',20);
end

% format output
%c=reshape(c,[nlags D(2:end)]);
bound = 1.96/sqrt(length(y));  

