function [k theta VEST]=SAIL(trce,trceTime)
% Infer the parameters of the alternating Gamma renewal process
% Input: trace, probing sending time
% Steps: 1. infer the parameters using HSMM algorithm
%        2. Compute the Variance using inverse laplace transfrom
% Output: 1. Parameters of the process
%          2. Variance
% copyright: hung.nguyen@adelaide.edu.au
%%%%%%%%%

clear k theta rhotd omegatd scaling F tau RTau 

n_samples=length(trce);


disp('Calling HSMM ...');


% %%% Running Yu's algorithm
% tic
% [k theta] =YU(trce,trceTime);
% k
% theta
% toc

% %%%% Running my implementation of Yu's algorithm
% tic
% [k theta  rhotd omegatd scaling] = EM_No_Limit(trce,trceTime);
% toc

%%% Running my  algorithm
tic
[k theta  rhotd omegatd scaling] = FB(trce,trceTime);
toc


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%% GETTING THE VARIANCE FOR THE GAMMA DISTRIBUTION
clear temp_laplace_fun
% Prepare the laplace function
F=strcat(num2str(k(1)),'*',num2str(theta(1)),'./((',num2str(k(1)*theta(1) + k(2)*theta(2)),')*s)');
F=strcat(F,'-((',num2str(theta(1)),'*s+1).^',num2str(k(1)),'-1).*((',num2str(theta(2)),'*s+1).^',num2str(k(2)),'-1)');
F=strcat(F,'./','(s.^2*', '(',num2str(k(1)*theta(1) + k(2)*theta(2)),').*','((',num2str(theta(1)),'*s+1).^',num2str(k(1)),'.*(',num2str(theta(2)),'*s+1).^',num2str(k(2)),'-1))');
fid=fopen('temp_laplace_fun.m','w');
fprintf(fid,'function F=temp_laplace_fun(s)');
fprintf(fid,'\n');
fprintf(fid,'	F=');
fprintf(fid,F);
fprintf(fid,';');
fclose(fid);

%Compute the max time lag
tauInt=0.5;
tauMax=floor(abs(trceTime(length(trceTime))-trceTime(1))/tauInt)+1;
tau=[10^-10:tauInt:tauMax];

%%Perform inverse lapplace transform
disp('Calling Inverse Laplace ...');
tic
RTau=invlap('temp_laplace_fun',tau);
toc

%%% Center the autocoveriance function
RTau= Rtau - (k(1)*theta(1)/sum(k.*theta))^2;


%%%% Checking the assymptotic variance
if ((sum(RTau) < 0)||(2*sum(RTau)/length(RTau)>1))
    disp('Inverse Laplace transform failed. Recompute the Autocovariance using simulation');
    tic
    RTau = GETAUTOCOV(k,theta,tau);
    toc
end

%%%% Compute the variance
VEST=0;
for i=1:n_samples
    for j =1:n_samples
        idx=floor(abs(trceTime(i)-trceTime(j))/tauInt)+1;
        if idx<= length(RTau)
            VEST=VEST+RTau(idx);  
        end
    end
end
VEST=VEST/n_samples^2;



